===================
Continuum Mechanics
===================


.. image:: https://img.shields.io/pypi/v/continuum_mechanics.svg
    :target: https://pypi.python.org/pypi/continuum_mechanics

.. image:: https://img.shields.io/travis/nicoguaro/continuum_mechanics.svg
    :target: https://travis-ci.org/nicoguaro/continuum_mechanics

.. image:: https://readthedocs.org/projects/continuum-mechanics/badge/?version=latest
    :target: https://continuum-mechanics.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://pyup.io/repos/github/nicoguaro/continuum_mechanics/shield.svg
    :target: https://pyup.io/repos/github/nicoguaro/continuum_mechanics/
    :alt: Updates

.. image:: https://mybinder.org/badge_logo.svg
    :target: https://mybinder.org/v2/gh/nicoguaro/continuum_mechanics/master

.. image:: https://img.shields.io/pypi/dm/continuum_mechanics
    :target: https://pypistats.org/packages/continuum-mechanics

.. image:: https://zenodo.org/badge/130519974.svg
   :target: https://zenodo.org/badge/latestdoi/130519974

Utilities for doing calculations in continuum mechanics.


* Free software: `MIT license <https://opensource.org/licenses/MIT>`__.
* Documentation: https://continuum-mechanics.readthedocs.io.


Features
--------

* Make long vector calculus calculations simple.
* Support different coordinate systems.
* Visualize entities such as second rank tensors.


Citation
--------

To cite `continuum_mechanics` in publications use

    Nicolás Guarín-Zapata. (2020). nicoguaro/continuum_mechanics: Version 0.2.1
    (Version v0.2.1). Zenodo. http://doi.org/10.5281/zenodo.4029448

A BibTeX entry for LaTeX users is

.. code:: bibtex

    @software{continuum_mechanics,
     title = {continuum_mechanics: Continuum Mechanics calculations in Python},
     version = {0.2.1},
     author = {Guarín-Zapata, Nicolás},
     year = 2020,
     keywords = {Python, Finite elements, Scientific computing, Computational mechanics},
     abstract = {`continuum_mechanics` is a Python package built on top of SymPy to aid
        with calculations in Continuum Mechanics that are commonly lengthy and
        tedious if done by hand. It also provides visualization capabilities for
        second-order tensors such as Mohr's circle to help in stress analyses.},
     url = {https://github.com/nicoguaro/continuum_mechanics},
     doi = {http://doi.org/10.5281/zenodo.4029448}
    }

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
